@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ class MplayerWindow;
 
 class QLabel;
 class FilePropertiesDialog;
-class VideoEqualizer;
+class VideoEqualizer2;
 class AudioEqualizer;
 class Playlist;
 #ifdef FIND_SUBTITLES
@@ -51,14 +51,16 @@ class FindSubtitlesWindow;
 class VideoPreview;
 #endif
 
-
 class MyAction;
 class MyActionGroup;
-
 class PreferencesDialog;
-
 class Favorites;
 class TVList;
+class UpdateChecker;
+
+#if !defined(Q_OS_WIN) || defined(PORTABLE_APP)
+#define REMINDER_ACTIONS 1
+#endif
 
 class BaseGui : public QMainWindow
 {
@@ -100,13 +102,19 @@ public slots:
 	virtual void openDirectory();
 	virtual void openDirectory(QString directory);
 
+	virtual void helpFirstSteps();
 	virtual void helpFAQ();
 	virtual void helpCLOptions();
 	virtual void helpCheckUpdates();
+#ifdef REMINDER_ACTIONS
+	virtual void helpDonate();
+#endif
 	virtual void helpShowConfig();
 	virtual void helpAbout();
 	virtual void helpAboutQt();
 
+	virtual void shareSMPlayer();
+
 	virtual void loadSub();
 	virtual void loadAudioFile(); // Load external audio file
 
@@ -121,7 +129,9 @@ public slots:
 	virtual void showVideoPreviewDialog();
 #endif
 
+#ifdef YOUTUBE_SUPPORT
 	virtual void showTubeBrowser();
+#endif
 
 	virtual void showPlaylist();
 	virtual void showPlaylist(bool b);
@@ -177,6 +187,7 @@ protected slots:
 	virtual void playlistHasFinished();
 
 	virtual void displayState(Core::State state);
+	virtual void displayMessage(QString message, int time);
 	virtual void displayMessage(QString message);
 	virtual void gotCurrentTime(double);
 
@@ -184,6 +195,8 @@ protected slots:
 	virtual void updateWidgets();
 	virtual void updateVideoEqualizer();
 	virtual void updateAudioEqualizer();
+	virtual void setDefaultValuesFromVideoEqualizer();
+	virtual void changeVideoEqualizerBySoftware(bool b);
 
 	virtual void newMediaLoaded();
 	virtual void updateMediaInfo();
@@ -195,13 +208,35 @@ protected slots:
 	void displayWarningAboutOldMplayer();
 #endif
 
+#ifdef UPDATE_CHECKER
+	void reportNewVersionAvailable(QString);
+#endif
+
+#ifdef CHECK_UPGRADED
+	void checkIfUpgraded();
+#endif
+
+#ifdef REMINDER_ACTIONS
+	void checkReminder();
+#endif
+
+#ifdef YOUTUBE_SUPPORT
+	void YTNoSignature(const QString &);
+	#ifdef YT_USE_SCRIPT
+	void YTUpdateScript();
+	#endif
+#endif
+
 #if AUTODISABLE_ACTIONS
 	virtual void enableActionsOnPlaying();
 	virtual void disableActionsOnStop();
 	virtual void togglePlayAction(Core::State);
 #endif
 
-	virtual void resizeWindow(int w, int h);
+	void changeSizeFactor(int factor);
+	void toggleDoubleSize();
+	void resizeMainWindow(int w, int h);
+	void resizeWindow(int w, int h);
 	virtual void hidePanel();
 
 	/* virtual void playlistVisibilityChanged(); */
@@ -297,6 +332,9 @@ signals:
 	//! Sent when the user wants to close the main window
 	void quitSolicited();
 
+	//! Sent when another instance requested to play a file
+	void openFileRequested();
+
 #ifdef GUI_CHANGE_ON_RUNTIME
 	void guiChanged(QString gui);
 #endif
@@ -442,7 +480,9 @@ protected:
 	MyAction * showPlaylistAct;
 	MyAction * showPropertiesAct;
 	MyAction * showPreferencesAct;
+#ifdef YOUTUBE_SUPPORT
 	MyAction * showTubeBrowserAct;
+#endif
 #ifdef LOG_MPLAYER
 	MyAction * showLogMplayerAct;
 #endif
@@ -451,13 +491,26 @@ protected:
 #endif
 
 	// Menu Help
+	MyAction * showFirstStepsAct;
 	MyAction * showFAQAct;
 	MyAction * showCLOptionsAct; // Command line options
 	MyAction * showCheckUpdatesAct;
+#if defined(YOUTUBE_SUPPORT) && defined(YT_USE_SCRIPT)
+	MyAction * updateYTAct;
+#endif
 	MyAction * showConfigAct;
+#ifdef REMINDER_ACTIONS
+	MyAction * donateAct;
+#endif
 	MyAction * aboutQtAct;
 	MyAction * aboutThisAct;
 
+	MyAction * facebookAct;
+	MyAction * twitterAct;
+	MyAction * gmailAct;
+	MyAction * hotmailAct;
+	MyAction * yahooAct;
+
 	// Playlist
 	MyAction * playPrevAct;
 	MyAction * playNextAct;
@@ -594,6 +647,15 @@ protected:
 	MyAction * ccChannel3Act;
 	MyAction * ccChannel4Act;
 
+	// External sub fps Group
+	MyActionGroup * subFPSGroup;
+	MyAction * subFPSNoneAct;
+	/* MyAction * subFPS23Act; */
+	MyAction * subFPS23976Act;
+	MyAction * subFPS24Act;
+	MyAction * subFPS25Act;
+	MyAction * subFPS29970Act;
+	MyAction * subFPS30Act;
 
 	// Audio Channels Action Group
 	MyActionGroup * channelsGroup;
@@ -609,6 +671,8 @@ protected:
 	MyAction * stereoAct;
 	MyAction * leftChannelAct;
 	MyAction * rightChannelAct;
+	MyAction * monoAct;
+	MyAction * reverseAct;
 
 	// Other groups
 #if PROGRAM_SWITCH
@@ -675,6 +739,9 @@ protected:
 	QMenu * screen_menu;
 #endif
 	QMenu * closed_captions_menu;
+	QMenu * subfps_menu;
+
+	QMenu * share_menu;
 
 	QMenu * popup;
 	QMenu * recentfiles_menu;
@@ -690,7 +757,7 @@ protected:
 	PreferencesDialog *pref_dialog;
 	FilePropertiesDialog *file_dialog;
 	Playlist * playlist;
-	VideoEqualizer * video_equalizer;
+	VideoEqualizer2 * video_equalizer2;
 	AudioEqualizer * audio_equalizer;
 #ifdef FIND_SUBTITLES
 	FindSubtitlesWindow * find_subs_dialog;
@@ -707,6 +774,10 @@ protected:
 	TVList * tvlist;
 	TVList * radiolist;
 
+#ifdef UPDATE_CHECKER
+	UpdateChecker * update_checker;
+#endif
+
 	QStringList actions_list;
 
 	QString pending_actions_to_run;
