@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -61,7 +61,6 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags)
 	ignore_playlist_events = false;
 #endif
 
-
 	mainwindow_pos = pos();
 
 	tray = new QSystemTrayIcon( Images::icon("logo", 22), this );
@@ -145,6 +144,8 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags)
              this, SLOT(dockVisibilityChanged(bool)) );
 #endif // USE_DOCK_TOPLEVEL_EVENT
 
+	connect(this, SIGNAL(openFileRequested()), this, SLOT(showAll()));
+
 	ignore_playlist_events = false;
 #endif // DOCK_PLAYLIST
 
@@ -305,6 +306,10 @@ void BaseGuiPlus::toggleShowAll() {
 	}
 }
 
+void BaseGuiPlus::showAll() {
+	if (!isVisible()) showAll(true);
+}
+
 void BaseGuiPlus::showAll(bool b) {
 	if (!b) {
 		// Hide all
