@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -220,7 +220,9 @@ void DefaultGui::createMainToolBars() {
 	QStringList toolbar1_actions;
 	toolbar1_actions << "open_file" << "open_url" << "favorites_menu" << "separator"
                      << "screenshot" << "separator" << "show_file_properties" << "show_playlist"
-                     << "show_preferences" << "separator" << "play_prev" << "play_next";
+                     << "show_tube_browser" << "separator" << "show_preferences"
+                     << "separator" << "play_prev" << "play_next";
+
 	toolbar1->setDefaultActions(toolbar1_actions);
 #else
 	toolbar1->addAction(openFileAct);
@@ -279,6 +281,7 @@ void DefaultGui::createControlWidgetMini() {
 
 	controlwidget_mini = new EditableToolbar( this );
 	controlwidget_mini->setObjectName("controlwidget_mini");
+	controlwidget_mini->setLayoutDirection(Qt::LeftToRight);
 	//controlwidget_mini->setResizeEnabled(false);
 	controlwidget_mini->setMovable(false);
 	//addDockWindow(controlwidget_mini, Qt::DockBottom );
@@ -315,6 +318,7 @@ void DefaultGui::createControlWidget() {
 
 	controlwidget = new EditableToolbar( this );
 	controlwidget->setObjectName("controlwidget");
+	controlwidget->setLayoutDirection(Qt::LeftToRight);
 	//controlwidget->setResizeEnabled(false);
 	controlwidget->setMovable(false);
 	//addDockWindow(controlwidget, Qt::DockBottom );
@@ -377,6 +381,7 @@ void DefaultGui::createControlWidget() {
 void DefaultGui::createFloatingControl() {
 	// Floating control
 	floating_control = new FloatingWidget(this);
+	floating_control->setLayoutDirection(Qt::LeftToRight);
 
 #if USE_CONFIGURABLE_TOOLBARS
 	QStringList floatingcontrol_actions;
@@ -428,8 +433,11 @@ void DefaultGui::createFloatingControl() {
 
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 	// To make work the ESC key (exit fullscreen) and Ctrl-X (close) in Windows and OS2
+	/*
 	floating_control->addAction(exitFullscreenAct);
 	floating_control->addAction(exitAct);
+	*/
+	floating_control->addActions(actions());
 #endif
 
 #if !USE_CONFIGURABLE_TOOLBARS
@@ -723,6 +731,7 @@ void DefaultGui::saveConfig() {
 		qDebug("DefaultGui::saveConfig: w: %d h: %d", width(), height());
 		set->setValue( "pos", pos() );
 		set->setValue( "size", size() );
+		set->setValue( "state", (int) windowState() );
 	}
 
 	set->setValue( "toolbars_state", saveState(Helper::qtVersion()) );
@@ -766,6 +775,8 @@ void DefaultGui::loadConfig() {
 		move(p);
 		resize(s);
 
+		setWindowState( (Qt::WindowStates) set->value("state", 0).toInt() );
+
 		if (!DesktopInfo::isInsideScreen(this)) {
 			move(0,0);
 			qWarning("DefaultGui::loadConfig: window is outside of the screen, moved to 0x0");
