@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,7 +25,9 @@ ErrorDialog::ErrorDialog( QWidget* parent, Qt::WindowFlags f )
 	setupUi(this);
 
 	icon->setText("");
-	icon->setPixmap( Images::icon("warning") );
+	icon->setPixmap( Images::icon("crash") );
+
+	intro_label->setText("<html><head/><body><p align=\"left\"><span style=\"font-size:14pt; font-weight:600;\">" + tr("Oops, something wrong happened") +"</span></p></body></html>");
 
 	text->setText("");
 	toggleLog(false);
