@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -51,10 +51,11 @@ Extensions::Extensions()
            << "bin" << "iso" << "vob"
            << "mkv" << "nsv" << "ram" << "flv"
            << "rm" << "swf"
-           << "ts" << "rmvb" << "dvr-ms" << "m2t" << "m2ts" << "rec" << "wtv"
-           << "f4v" << "hdmov" << "webm" << "vp8" ;
+           << "ts" << "rmvb" << "dvr-ms" << "m2t" << "m2ts" << "mts" << "rec" << "wtv"
+           << "f4v" << "hdmov" << "webm" << "vp8"
+           << "bik" << "smk" ;
 
-	_audio << "mp3" << "ogg" << "oga" << "wav" << "wma" <<  "ac3" << "ra" << "ape" << "flac" << "thd" << "mka" << "m4a";
+	_audio << "mp3" << "ogg" << "oga" << "wav" << "wma" <<  "aac" << "ac3" << "dts" << "ra" << "ape" << "flac" << "thd" << "mka" << "m4a";
 
 	_subtitles << "srt" << "sub" << "ssa" << "ass" << "idx" << "txt" << "smi"
                << "rt" << "utf" << "aqt";
