@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,6 +31,9 @@ public:
 	//! Returns the ISO_639-1 language list
 	static QMap<QString,QString> list();
 
+	//! List with the most used languages
+	static QMap<QString,QString> most_used_list();
+
 	//! Returns the list of translations available
 	static QMap<QString,QString> translations();
 
