@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -96,7 +96,11 @@ void MplayerProcess::writeToStdin(QString text) {
 	if (isRunning()) {
 		//qDebug("MplayerProcess::writeToStdin");
 #if !defined(Q_OS_OS2)
+		#ifdef Q_OS_WIN
+		write( text.toUtf8() + "\n");
+		#else
 		write( text.toLocal8Bit() + "\n");
+		#endif
 #else
 		MPpipeWrite( text.toLocal8Bit() + "\n");
 #endif
@@ -163,6 +167,7 @@ static QRegExp rx_paused("^ID_PAUSED");
 static QRegExp rx_novideo("^Video: no video");
 #endif
 static QRegExp rx_cache("^Cache fill:.*");
+static QRegExp rx_cache_empty("^Cache empty.*|^Cache not filling.*");
 static QRegExp rx_create_index("^Generating Index:.*");
 static QRegExp rx_play("^Starting playback...");
 static QRegExp rx_connecting("^Connecting to .*");
@@ -226,7 +231,11 @@ void MplayerProcess::parseLine(QByteArray ba) {
 #if COLOR_OUTPUT_SUPPORT
     QString line = ColorUtils::stripColorsTags(QString::fromLocal8Bit(ba));
 #else
+	#ifdef Q_OS_WIN
+	QString line = QString::fromUtf8(ba);
+	#else
 	QString line = QString::fromLocal8Bit(ba);
+	#endif
 #endif
 
 	// Parse A: V: line
@@ -466,6 +475,10 @@ void MplayerProcess::parseLine(QByteArray ba) {
 		}
 #endif
 
+		if (rx_cache_empty.indexIn(line) > -1) {
+			emit receivedCacheEmptyMessage(line);
+		}
+
 		// The following things are not sent when the file has started to play
 		// (or if sent, smplayer will ignore anyway...)
 		// So not process anymore, if video is playing to save some time
