@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -46,6 +46,7 @@
 #include "helper.h"
 #include "images.h"
 #include "preferences.h"
+#include "multilineinputdialog.h"
 #include "version.h"
 #include "global.h"
 #include "core.h"
@@ -214,6 +215,9 @@ void Playlist::createActions() {
 	addDirectoryAct = new MyAction(this, "pl_add_directory", false);
 	connect( addDirectoryAct, SIGNAL(triggered()), this, SLOT(addDirectory()) );
 
+	addUrlsAct = new MyAction(this, "pl_add_urls", false);
+	connect( addUrlsAct, SIGNAL(triggered()), this, SLOT(addUrls()) );
+
 	// Remove actions
 	removeSelectedAct = new MyAction(this, "pl_remove_selected", false);
 	connect( removeSelectedAct, SIGNAL(triggered()), this, SLOT(removeSelected()) );
@@ -238,6 +242,7 @@ void Playlist::createToolbar() {
 	add_menu->addAction(addCurrentAct);
 	add_menu->addAction(addFilesAct );
 	add_menu->addAction(addDirectoryAct);
+	add_menu->addAction(addUrlsAct);
 
 	add_button = new QToolButton( this );
 	add_button->setMenu( add_menu );
@@ -288,15 +293,9 @@ void Playlist::retranslateStrings() {
 	nextAct->change( tr("&Next") );
 	prevAct->change( tr("Pre&vious") );
 
-	if (qApp->isLeftToRight()) {
-		playAct->setIcon( Images::icon("play") );
-		nextAct->setIcon( Images::icon("next") );
-		prevAct->setIcon( Images::icon("previous") );
-	} else {
-		playAct->setIcon( Images::flippedIcon("play") );
-		nextAct->setIcon( Images::flippedIcon("next") );
-		prevAct->setIcon( Images::flippedIcon("previous") );
-	}
+	playAct->setIcon( Images::icon("play") );
+	nextAct->setIcon( Images::icon("next") );
+	prevAct->setIcon( Images::icon("previous") );
 
 	moveUpAct->change( Images::icon("up"), tr("Move &up") );
 	moveDownAct->change( Images::icon("down"), tr("Move &down") );
@@ -308,6 +307,7 @@ void Playlist::retranslateStrings() {
 	addCurrentAct->change( tr("Add &current file") );
 	addFilesAct->change( tr("Add &file(s)") );
 	addDirectoryAct->change( tr("Add &directory") );
+	addUrlsAct->change( tr("Add &URL(s)") );
 
 	// Remove actions
 	removeSelectedAct->change( tr("Remove &selected") );
@@ -389,11 +389,7 @@ void Playlist::updateView() {
 
 void Playlist::setCurrentItem(int current) {
 	QIcon play_icon;
-	if (qApp->isLeftToRight()) {
-		play_icon = Images::icon("play");
-	} else {
-		play_icon = Images::flippedIcon("play");
-	}
+	play_icon = Images::icon("play");
 
 	int old_current = current_item;
 	current_item = current;
@@ -722,7 +718,7 @@ bool Playlist::save_m3u(QString file) {
 		QString filename;
 
 		stream << "#EXTM3U" << "\n";
-		stream << "# Playlist created by SMPlayer " << smplayerVersion() << " \n";
+		stream << "# Playlist created by SMPlayer " << Version::printable() << " \n";
 
 		PlaylistItemList::iterator it;
 		for ( it = pl.begin(); it != pl.end(); ++it ) {
@@ -1080,6 +1076,17 @@ void Playlist::addDirectory() {
 	}
 }
 
+void Playlist::addUrls() {
+	MultilineInputDialog d(this);
+	if (d.exec() == QDialog::Accepted) {
+		QStringList urls = d.lines();
+		foreach(QString u, urls) {
+			if (!u.isEmpty()) addItem( u, "", 0 );
+		}
+		updateView();
+	}
+}
+
 void Playlist::addOneDirectory(QString dir) {
 	QStringList filelist;
 
