@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,6 +29,10 @@
 #include "audioequalizerlist.h"
 #include "assstyles.h"
 
+#ifdef UPDATE_CHECKER
+#include "updatechecker.h"
+#endif
+
 class Recents;
 class URLHistory;
 class Filters;
@@ -314,6 +318,8 @@ public:
 	QString style; 	//!< SMPlayer look
 #endif
 
+	bool move_when_dragging; //!< Move the main window when the video area is dragged
+
 	// Function of mouse buttons:
 	QString mouse_left_click_function;
 	QString mouse_right_click_function;
@@ -344,6 +350,8 @@ public:
 #endif
 	bool precise_seeking; //! Enable precise_seeking (only available with mplayer2)
 
+	bool reset_stop; //! Pressing the stop button resets the position
+
 	QString language;
 	QString iconset;
 
@@ -499,10 +507,22 @@ public:
        SMPlayer info
        ********* */
 
+#ifdef CHECK_UPGRADED
+	QString smplayer_stable_version;
+	bool check_if_upgraded;
+#endif
 #ifdef FONTCACHE_DIALOG
 	QString smplayer_version;
 #endif
 
+
+    /* *********
+       Update
+       ********* */
+
+#ifdef UPDATE_CHECKER
+	UpdateCheckerData update_checker_data;
+#endif
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Preferences::WheelFunctions)
