@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include "prefadvanced.h"
 #include "prefplaylist.h"
 #include "preftv.h"
+#include "prefupdates.h"
 
 #if USE_ASSOCIATIONS
 #include "prefassociations.h"
@@ -93,6 +94,9 @@ PreferencesDialog::PreferencesDialog(QWidget * parent, Qt::WindowFlags f)
 	addSection(page_associations);
 #endif
 
+	page_updates = new PrefUpdates;
+	addSection( page_updates );
+
 	page_advanced = new PrefAdvanced;
 	addSection( page_advanced );
 
@@ -174,6 +178,7 @@ void PreferencesDialog::setData(Preferences * pref) {
 	page_advanced->setData(pref);
 	page_playlist->setData(pref);
 	page_tv->setData(pref);
+	page_updates->setData(pref);
 
 #if USE_ASSOCIATIONS
 	page_associations->setData(pref);
@@ -190,6 +195,7 @@ void PreferencesDialog::getData(Preferences * pref) {
 	page_advanced->getData(pref);
 	page_playlist->getData(pref);
 	page_tv->getData(pref);
+	page_updates->getData(pref);
 
 #if USE_ASSOCIATIONS
 	page_associations->getData(pref);
@@ -206,6 +212,7 @@ bool PreferencesDialog::requiresRestart() {
 	if (!need_restart) need_restart = page_advanced->requiresRestart();
 	if (!need_restart) need_restart = page_playlist->requiresRestart();
 	if (!need_restart) need_restart = page_tv->requiresRestart();
+	if (!need_restart) need_restart = page_updates->requiresRestart();
 
 	return need_restart;
 }
