@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -151,6 +151,9 @@ void SkinGui::createActions() {
 #endif
 
 	playOrPauseAct->setCheckable(true);
+
+	viewVideoInfoAct = new MyAction(this, "toggle_video_info_skingui" );
+	viewVideoInfoAct->setCheckable(true);
 }
 
 #if AUTODISABLE_ACTIONS
@@ -201,6 +204,10 @@ void SkinGui::createMenus() {
 #endif
 	optionsMenu->addSeparator();
 	optionsMenu->addMenu(toolbar_menu);
+
+	statusbar_menu = new QMenu(this);
+	statusbar_menu->addAction(viewVideoInfoAct);
+	optionsMenu->addMenu(statusbar_menu);
 }
 
 QMenu * SkinGui::createPopupMenu() {
@@ -259,6 +266,7 @@ void SkinGui::createControlWidget() {
 
 	controlwidget = new QToolBar( this );
 	controlwidget->setObjectName("controlwidget");
+	controlwidget->setLayoutDirection(Qt::LeftToRight);
 	controlwidget->setStyleSheet("QToolBar { spacing: 0px; }");
 	controlwidget->setMovable(false);
 	addToolBar(Qt::BottomToolBarArea, controlwidget);
@@ -296,6 +304,7 @@ void SkinGui::createControlWidget() {
 	mediaBarPanel->setToolbarActionCollection(actions);
 
 	connect(mediaBarPanel, SIGNAL(volumeChanged(int)), core, SLOT(setVolume(int)));
+	connect(mediaBarPanel, SIGNAL(volumeSliderMoved(int)), core, SLOT(setVolume(int)));
 	connect(core, SIGNAL(volumeChanged(int)), mediaBarPanel, SLOT(setVolume(int)));
 
 #ifdef SEEKBAR_RESOLUTION
@@ -306,6 +315,9 @@ void SkinGui::createControlWidget() {
 	connect(core, SIGNAL(posChanged(int)),mediaBarPanel, SLOT(setSeeker(int)));
 #endif
 
+	connect( viewVideoInfoAct, SIGNAL(toggled(bool)),
+             mediaBarPanel, SLOT(setResolutionVisible(bool)) );
+
 	controlwidget->addWidget(mediaBarPanel);
 }
 
@@ -380,6 +392,9 @@ void SkinGui::retranslateStrings() {
 	toolbar_menu->menuAction()->setText( tr("&Toolbars") );
 	toolbar_menu->menuAction()->setIcon( Images::icon("toolbars") );
 
+	statusbar_menu->menuAction()->setText( tr("Status&bar") );
+	statusbar_menu->menuAction()->setIcon( Images::icon("statusbar") );
+
 	toolbar1->setWindowTitle( tr("&Main toolbar") );
 	toolbar1->toggleViewAction()->setIcon(Images::icon("main_toolbar"));
 
@@ -390,6 +405,8 @@ void SkinGui::retranslateStrings() {
 	#endif
 #endif
 
+	viewVideoInfoAct->change(Images::icon("view_video_info"), tr("&Video info") );
+
 	mediaBarPanel->setVolume(core->mset.volume);
 }
 
@@ -407,6 +424,11 @@ void SkinGui::displayState(Core::State state) {
 	}
 }
 
+void SkinGui::displayMessage(QString message, int time) {
+	BaseGuiPlus::displayMessage(message, time);
+	mediaBarPanel->displayMessage(message, time);
+}
+
 void SkinGui::displayMessage(QString message) {
 	BaseGuiPlus::displayMessage(message);
 	mediaBarPanel->displayMessage(message);
@@ -523,6 +545,8 @@ void SkinGui::saveConfig() {
 
 	set->beginGroup( "skin_gui");
 
+	set->setValue("video_info", viewVideoInfoAct->isChecked());
+
 	set->setValue("fullscreen_toolbar1_was_visible", fullscreen_toolbar1_was_visible);
 	set->setValue("compact_toolbar1_was_visible", compact_toolbar1_was_visible);
 
@@ -530,6 +554,7 @@ void SkinGui::saveConfig() {
 		qDebug("SkinGui::saveConfig: w: %d h: %d", width(), height());
 		set->setValue( "pos", pos() );
 		set->setValue( "size", size() );
+		set->setValue( "state", (int) windowState() );
 	}
 
 	set->setValue( "toolbars_state", saveState(Helper::qtVersion()) );
@@ -554,6 +579,8 @@ void SkinGui::loadConfig() {
 
 	set->beginGroup( "skin_gui");
 
+	viewVideoInfoAct->setChecked(set->value("video_info", false).toBool());
+
 	fullscreen_toolbar1_was_visible = set->value("fullscreen_toolbar1_was_visible", fullscreen_toolbar1_was_visible).toBool();
 	compact_toolbar1_was_visible = set->value("compact_toolbar1_was_visible", compact_toolbar1_was_visible).toBool();
 
@@ -568,6 +595,8 @@ void SkinGui::loadConfig() {
 		move(p);
 		resize(s);
 
+		setWindowState( (Qt::WindowStates) set->value("state", 0).toInt() );
+
 		if (!DesktopInfo::isInsideScreen(this)) {
 			move(0,0);
 			qWarning("SkinGui::loadConfig: window is outside of the screen, moved to 0x0");
