@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include "version.h"
 #include "config.h"
 #include "clhelp.h"
+#include "cleanconfig.h"
 #include "myapplication.h"
 
 #ifdef SKINS
@@ -61,7 +62,7 @@ SMPlayer::SMPlayer(const QString & config_path, QObject * parent )
 	allow_to_send_log_to_gui = true;
 #endif
 
-	gui_to_use = "DefaultGui";
+	gui_to_use = "DefaultGUI";
 
 	close_at_end = -1; // Not set
 	start_in_fullscreen = -1; // Not set
@@ -99,6 +100,25 @@ BaseGui * SMPlayer::gui() {
 		qDebug("SMPlayer::gui: changed working directory to app path");
 		qDebug("SMPlayer::gui: current directory: %s", QDir::currentPath().toUtf8().data());
 
+#ifdef SKINS
+		if (gui_to_use == "SkinGUI") {
+			QString theme = pref->iconset;
+			if (theme.isEmpty()) theme = "Gonzo";
+			QString user_theme_dir = Paths::configPath() + "/themes/" + theme;
+			QString theme_dir = Paths::themesPath() + "/" + theme;
+			qDebug("SMPlayer::gui: user_theme_dir: %s", user_theme_dir.toUtf8().constData());
+			qDebug("SMPlayer::gui: theme_dir: %s", theme_dir.toUtf8().constData());
+			if ((QDir(theme_dir).exists()) || (QDir(user_theme_dir).exists())) {
+				if (pref->iconset.isEmpty()) pref->iconset = theme;
+			} else {
+				qDebug("SMPlayer::gui: skin folder doesn't exist. Falling back to default gui.");
+				gui_to_use = "DefaultGUI";
+				pref->iconset = "";
+				pref->gui = gui_to_use;
+			}
+		}
+#endif
+
 		main_window = createGUI(gui_to_use);
 
 		if (move_gui) {
@@ -187,8 +207,8 @@ SMPlayer::ExitCode SMPlayer::processArgs(QStringList args) {
 	bool add_to_playlist = false;
 
 #ifdef Q_OS_WIN
-	if (args.contains("-uninstall")){
-#if USE_ASSOCIATIONS
+	if (args.contains("-uninstall")) {
+		#if USE_ASSOCIATIONS
 		//Called by uninstaller. Will restore old associations.
 		WinFileAssoc RegAssoc; 
 		Extensions exts; 
@@ -196,11 +216,16 @@ SMPlayer::ExitCode SMPlayer::processArgs(QStringList args) {
 		RegAssoc.GetRegisteredExtensions(exts.multimedia(), regExts); 
 		RegAssoc.RestoreFileAssociations(regExts); 
 		printf("Restored associations\n");
-#endif
-		return NoError; 
+		#endif
+		return NoError;
 	}
 #endif
 
+	if (args.contains("-delete-config")) {
+		CleanConfig::clean(Paths::configPath());
+		return NoError;
+	}
+
 	for (int n = 1; n < args.count(); n++) {
 		QString argument = args[n];
 
@@ -294,16 +319,22 @@ SMPlayer::ExitCode SMPlayer::processArgs(QStringList args) {
 		}
 		else
 		if (argument == "-mini" || argument == "-minigui") {
-			gui_to_use = "MiniGui";
+			gui_to_use = "MiniGUI";
 		}
 		else
 		if (argument == "-mpcgui") {
-			gui_to_use = "MpcGui";
+			gui_to_use = "MpcGUI";
 		}
 		else
 		if (argument == "-defaultgui") {
-			gui_to_use = "DefaultGui";
+			gui_to_use = "DefaultGUI";
 		}
+#ifdef SKINS
+		else
+		if (argument == "-skingui") {
+			gui_to_use = "SkinGUI";
+		}
+#endif
 		else {
 			// File
 			#if QT_VERSION >= 0x040600
@@ -369,10 +400,10 @@ SMPlayer::ExitCode SMPlayer::processArgs(QStringList args) {
 void SMPlayer::start() {
 #ifdef FONTCACHE_DIALOG
 #ifndef PORTABLE_APP
-	if (smplayerVersion() != pref->smplayer_version) {
+	if (Version::with_revision() != pref->smplayer_version) {
 		FontCacheDialog d(0);
 		d.run(pref->mplayer_bin, "sample.avi");
-		pref->smplayer_version = smplayerVersion();
+		pref->smplayer_version = Version::with_revision();
 	}
 #endif
 #endif
@@ -430,7 +461,7 @@ void SMPlayer::showInfo() {
 	}
 #endif
 	QString s = QObject::tr("This is SMPlayer v. %1 running on %2")
-            .arg(smplayerVersion())
+            .arg(Version::printable())
 #ifdef Q_OS_LINUX
            .arg("Linux")
 #else
